@@ -3,13 +3,13 @@
 # Description: Python package for computing, analysing and visualising 
 # early warning signals (EWS) in time-series data
 # Author: Thomas M Bury
-# Web: http://www.math.uwaterloo.ca/~tbury/
+# Web: https://www.thomasbury.net/
 # Code repo: https://github.com/ThomasMBury/ewstools
 # Documentation: https://ewstools.readthedocs.io/
 #
 # The MIT License (MIT)
 #
-# Copyright (c) 2019 Thomas Bury http://www.math.uwaterloo.ca/~tbury/
+# Copyright (c) 2019 Thomas Bury
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -114,8 +114,8 @@ def pspec_welch(yVals,
                                scaling=scaling)
     
     # Put into a pandas series and index by frequency (scaled by 2*pi)
-    pspec_series = pd.Series(pspec_raw[1], index=2*np.pi*pspec_raw[0], name='Power spectrum')
-    pspec_series.index.name = 'Frequency'
+    pspec_series = pd.Series(pspec_raw[1], index=2*np.pi*pspec_raw[0], name='power')
+    pspec_series.index.name = 'frequency'
     
     # Sort into ascending frequency
     pspec_series.sort_index(inplace=True)
@@ -228,7 +228,6 @@ def shopf_init(smax, stot, wdom):
 
 
     
-    
 def sfold_init(smax, stot):
     '''
     Compute the 'best guess' initialisation values for sigma and lamda
@@ -573,7 +572,6 @@ def aic_weights(aic_scores):
 
 #-----------Compute spectral metrics (EWS) from power spectrum------#
 
-
 def pspec_metrics(pspec,
                   ews = ['smax','cf','aic'],
                   aic = ['Fold','Hopf','Null'],
@@ -826,7 +824,7 @@ def compute_autocov(df_in):
     Computes the autocovariance (lag-1) matrix of n 
     time series provided in df_in.
     Using the definition
-        phi_ij = < X_i(t+1) X_j(t) >
+    phi_ij = < X_i(t+1) X_j(t) >
     for each element of the autocovariance matrix phi.
         
     Args
@@ -930,15 +928,14 @@ def eval_recon(df_in):
     -------------------
         df_in: DataFrame with two columns indexed by time
         
-        
     Return
     -------------------
     dict
-		Consists of
-			- 'Eigenvalues': np.array of eigenvalues
-    		- 'Eigenvectors': np.array of eigenvectors
-    		- 'Jacobian': pd.DataFrame of Jacobian entries
-    		
+		Consists of 'Eigenvalues': np.array of eigenvalues. 
+		'Eigenvectors': np.array of eigenvectors. 'Jacobian': pd.DataFrame of 
+		Jacobian entries.
+	
+
     '''
     
     # Get the time-separation between data points
